Learn R Programming

soilassessment (version 1.3.1)

calcSuit: Calculating suitability classes

Description

Function for calculating suitability classes given the target information. The function use given limits to calculate the suitability class

Usage

calcSuit(x, lm1,lm2,lm3,lm4)

Value

An interger representing suitability class. 1-High, 2-Moderate, 3-Low, 4-Not suitable

Arguments

x

Input value of the indicator to be classified

lm1

Upper limit of the highest class

lm2

Upper limit of the second highest class

lm3

Upper limit of the second last class

lm4

Maximum allowable limit for target variable

Author

Christian Thine Omuto

Details

The function calculates the boundary conditions for realistic values of target soil properties

See Also

classCode

Examples

Run this code
calcSuit(22,8,12,24,100)

Run the code above in your browser using DataLab