Learn R Programming

soilassessment (version 1.3.1)

getSuit: Deriving categorical suitability classes

Description

A generic model to derive suitability classes given the target information. The function uses provided limits to derive the suitability classes

Usage

getSuit(x,lim1,lim2,lim3,lim4)

Value

Suitability class values as integers. 1-High, 2-Moderate, 3-Low, 4-Not suitable

Arguments

x

Input value of the indicator to be classified

lim1

Lower limit of the highest class

lim2

Lower limit of the second highest class

lim3

Lower limit of the second last class

lim4

Maximum allowable limit for target variable

Author

Christian Thine Omuto

Details

The function puts the boundary conditions for realistic values of target soil properties

See Also

classLUT, classCode

Examples

Run this code
getSuit(1.67,1.2,1.3,1.5,2.6)

Run the code above in your browser using DataLab