View source: R/checkInternet.R
| checkInternet | R Documentation |
This is for testing and reporting url of remote servers for graceful fail in functions which use remote call
checkInternet(dbase_file)
dbase_file |
url address of the remote server |
It carries out three tests on the given url: 1- if the url fetch times out , 2- if there is no internet connection, and 3- if there is bad path name and passes a message when their is failure.
a response message (Time out or error 404 or No internet connection) or data.frame of available data
Christian Thine Omuto
xx="https://docs.google.com/spreadsheets/d/e"
checkInternet(xx)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.