checkInternet: Checking internet connectivity for functions with remote call
Description
This is for testing and reporting url of remote servers for graceful fail in functions which use remote call
Usage
checkInternet(dbase_file)
Value
a response message (Time out or error 404 or No internet connection) or data.frame of available data
Arguments
dbase_file
url address of the remote server
Author
Christian Thine Omuto
Details
It carries out three tests on the given url: 1- if the url fetch times out , 2- if there is no internet connection, and 3- if there is bad path name and passes a message when their is failure.