powered by
A generic model to derive suitability classes given the target information. The function uses provided limits to derive the suitability classes
getSuit(x,lim1,lim2,lim3,lim4)
Suitability class values as integers. 1-High, 2-Moderate, 3-Low, 4-Not suitable
Input value of the indicator to be classified
Lower limit of the highest class
Lower limit of the second highest class
Lower limit of the second last class
Maximum allowable limit for target variable
Christian Thine Omuto
The function puts the boundary conditions for realistic values of target soil properties
classLUT, classCode
classLUT
classCode
getSuit(1.67,1.2,1.3,1.5,2.6)
Run the code above in your browser using DataLab